#
# spec file for package skelcd-control-CAASP
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change the control file or this spec file
#   in build service directly, use
#   https://github.com/yast/skelcd-control-CAASP repository
#
#   See https://github.com/yast/skelcd-control-CAASP/blob/master/CONTRIBUTING.md
#   for more details.
#
######################################################################

Name:           skelcd-control-CAASP
# xmllint (for validation)
BuildRequires:  libxml2-tools
# RNG validation schema
BuildRequires:  yast2-installation-control >= 4.0.10

%if 0%{?is_opensuse}
# xsltproc - for building control.Kubic.xml from control.CAASP.xml
BuildRequires:  diffutils
BuildRequires:  libxslt-tools
# we need to copy some parts from the openSUSE control.xml to Kubic
BuildRequires:  skelcd-control-openSUSE
%endif

######################################################################
#
# Here is the list of Yast packages which are needed in the
# installation system (inst-sys) for the Yast installer
#

# SLES specific Yast packages needed in the inst-sys
# to provide the functionality needed by this control file
Requires:       yast2-registration
%if 0%{?is_susecaasp}
Requires:       yast2-theme-SLE
%else
Requires:       yast2-branding-openSUSE
Requires:       yast2-qt-branding-openSUSE
%endif

# the CaaSP specific packages
Requires:       yast2-caasp

# Generic Yast packages needed for the installer
Requires:       autoyast2
Requires:       yast2-add-on
Requires:       yast2-buildtools
Requires:       yast2-devtools
Requires:       yast2-fcoe-client
# For creating the AutoYast profile at the end of installation (bnc#887406)
Requires:       yast2-firewall
# instsys_cleanup
Requires:       yast2-installation >= 3.1.217.9
Requires:       yast2-iscsi-client
Requires:       yast2-kdump
Requires:       yast2-multipath
Requires:       yast2-network >= 3.1.42
Requires:       yast2-nfs-client
Requires:       yast2-ntp-client
Requires:       yast2-proxy
Requires:       yast2-services-manager
Requires:       yast2-slp
Requires:       yast2-trans-stats
Requires:       yast2-tune
Requires:       yast2-update
Requires:       yast2-users
Requires:       yast2-x11
# Ruby debugger in the inst-sys (FATE#318421)
Requires:       rubygem(%{rb_default_ruby_abi}:byebug)
# Install and enable xrdp by default (FATE#320363)
Requires:       yast2-rdp

# Ensure no two skelcd-control-* packages can be installed in the same time,
# an OBS check reports a file conflict for the /CD1/control.xml file from
# the other packages.
Conflicts:      product_control
Provides:       product_control

# Architecture specific packages
#
%ifarch s390 s390x
Requires:       yast2-reipl >= 3.1.4
Requires:       yast2-s390
%endif

%ifarch %ix86 x86_64
Requires:       yast2-vm
%endif

# SUSEConnect does not build for i586 and s390 and is not supported on those architectures
# bsc#1088552 so also yast2-registration is not there.
ExcludeArch:    %ix86 s390

#
######################################################################

Url:            https://github.com/yast/skelcd-control-CAASP
AutoReqProv:    off
Version:        15.0.15
Release:        lp150.1.2
Summary:        The CaaSP control file needed for installation
License:        MIT
Group:          Metapackages
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}-%{version}.tar.bz2

%if 0%{?suse_version} >= 1500 && !0%{?skelcd_compat}
%define skelcdpath /usr/lib/skelcd
%endif

%description
The package contains the CaaSP control file needed for installation.

%prep

%setup -n %{name}-%{version}

%if 0%{?is_opensuse}
%build
# build control.Kubic.xml from control.CAASP.xml
make -C control control.Kubic.xml
# display the changes (just for easier debugging)
# don't fail, a difference is expected
diff -u control/control.CAASP.xml control/control.Kubic.xml || :
%endif

%check
#
# Verify syntax
#
make -C control check

%install
#
# Add control file 
#
mkdir -p $RPM_BUILD_ROOT%{?skelcdpath}/CD1
%if 0%{?is_susecaasp}
install -m 644 control/control.CAASP.xml $RPM_BUILD_ROOT%{?skelcdpath}/CD1/control.xml
%else
%if 0%{?is_opensuse}
install -m 644 control/control.Kubic.xml $RPM_BUILD_ROOT%{?skelcdpath}/CD1/control.xml
%endif
%endif

# install LICENSE (required by build service check)
mkdir -p $RPM_BUILD_ROOT/%{_prefix}/share/doc/packages/%{name}
install -m 644 LICENSE $RPM_BUILD_ROOT/%{_prefix}/share/doc/packages/%{name}

%files
%defattr(644,root,root,755)
%if 0%{?is_susecaasp}%{?is_opensuse}
%if %{defined skelcdpath}
%dir %{skelcdpath}
%endif
%dir %{?skelcdpath}/CD1
%{?skelcdpath}/CD1/control.xml
%endif
%doc %dir %{_prefix}/share/doc/packages/%{name}
%doc %{_prefix}/share/doc/packages/%{name}/LICENSE

%changelog
* Tue Apr 10 2018 jreidinger@suse.com
- Do not build on 32-bit architecture as some dependencies are not
  available there (bsc#1088852)
- 15.0.15
* Tue Mar 13 2018 igonzalezsosa@suse.com
- Replace root_subvolume_read_only with btrfs_read_only (related
  to bsc#1079000).
- 15.0.14
* Fri Jan 26 2018 jsrain@suse.cz
- always use 'zypper dup' equivalent when doing upgrade
  (bsc#1071708)
- 15.0.13
* Thu Jan 18 2018 jsrain@suse.cz
- adjusted patterns list (bsc#1075998)
- defined role for plain MicroOS
- 15.0.12
* Tue Jan 16 2018 rbrown@suse.com
- do not define control.xml in %%files when not CaaSP or openSUSE
  (boo#1076173)
- 15.0.11
* Tue Jan 16 2018 rbrown@suse.com
- use Tumbleweed style skelcdpath control file location macros
  (boo#1076173)
- 15.0.10
* Tue Jan 16 2018 rbrown@suse.com
- correct spec to not install control file in SLE 15 staging
  (boo#1076173)
- 15.0.9
* Fri Jan 12 2018 rbrown@suse.com
- correct Kubic.xsl related spec refs to use %%is_opensuse instead
  of !%%is_susecaasp. skelcd-control-CaaSP is built for non-openSUSE
  products that are not susecaasp, and previous arrangement caused
  build failures. (boo#1075802)
- 15.0.8
* Tue Dec 12 2017 rbrown@suse.com
- adjust subvolume list to have NoCOW /var instead of many
  subvolumes (boo#1075369)
- 15.0.7
* Tue Dec  5 2017 lslezak@suse.cz
- openSUSE Kubic: copy "extra_urls" configuration from the standard
  openSUSE product (bsc#1071217)
- 15.0.6
* Thu Oct 26 2017 snwint@suse.de
- adjust subvolume list in control.xml to support all archs (fate#318196)
- 15.0.5
* Mon Oct 23 2017 snwint@suse.de
- Use new storage-ng elements for partitioning in control.xml (fate#318196)
- 15.0.4
* Thu Sep 21 2017 jreidinger@suse.cz
- Adapt to changes in roles (needed for fixing bsc#1049297)
- 15.0.3
* Tue Sep 19 2017 lslezak@suse.cz
- Patch control.Kubic.xml using a XSL file, that's more robust
  then a plain text diff (bsc#1059299)
- 15.0.2
* Mon Sep 18 2017 lslezak@suse.cz
- Adjust the install path for Kubic (openSUSE still uses the old
  product builder in OBS)
* Mon Sep 18 2017 rbrown@suse.com
- Adjust control.Kubic.diff, remove non-existing admin-node-setup
  service (bsc#1058749)
- 15.0.1
* Fri Sep  1 2017 lslezak@suse.cz
- Added yast2-s390 dependency to fix failed disk activation
  (bsc#1055871)
- 15.0.0
* Wed Aug 16 2017 shundhammer@suse.de
- Make filesystem type for home and root configurable (bsc#1051762)
- 12.2.38
* Tue Jul  4 2017 shundhammer@suse.de
- Reduce min size to create a separate /var/lib/docker partition
  to 35 GB (Fate#323532)
- 12.2.37
* Tue Jun 27 2017 jsrain@suse.cz
- enabled the admin-node-setup service on admin (bsc#1046162)
- 12.2.36
* Tue Jun 27 2017 jsrain@suse.cz
- added "swapaccount=1" to kernel parameters (fate#323562)
- 12.2.35
* Mon Jun 26 2017 shundhammer@suse.de
- Hack: Use home partition as /var/lib/docker (Fate#323532)
- 12.2.34
* Fri Jun 23 2017 knut.anderssen@suse.com
- Enable salt-minion service in dashboard role (bsc#1045350)
- 12.2.33
* Tue Jun 20 2017 jsrain@suse.cz
- added subvolume for /var/lib/ca-certificates (bsc#1045125)
- adjusted NoCoW attributes for subvolumes (bsc#1045125)
- enable docker on cluster nodes (bsc#1045125)
- 12.2.32
* Wed May 24 2017 behlert@suse.de
- /usr/lib/skelcd/CD1 instead of /CD1
* Wed May 17 2017 shundhammer@suse.de
- Added subvolume /home (bsc#1039237)
- 12.2.31
* Tue May  9 2017 lslezak@suse.cz
- Update the default pattern names (bsc#1038267)
- Adapt the package to build also for openSUSE (added
  control.Kubic.diff patch)
- 12.2.31
* Thu May  4 2017 lslezak@suse.cz
- The package has been renamed from skelcd-control-CASP to
  skelcd-control-CAASP (bsc#1037541)
- 12.2.30
* Thu May  4 2017 shundhammer@suse.de
- Added NoCOW subvolume /var/lib/dockershim (bsc#1037208)
- 12.2.29
* Tue Apr  4 2017 mvidner@suse.com
- bsc#1032057
  - Role names: Administration Node, Cluster Node, Plain System
  - Enable container-feeder and other services
- 12.2.28
* Tue Apr  4 2017 mvidner@suse.com
- Include yast2-caasp in the instsys (bsc#1032010).
- 12.2.27
* Thu Mar 16 2017 kanderssen@suse.com
- bsc#1029325
  - Added subvolume /var/lib/mysql without copy on write.
  - Disabled copy on write on /var/lib/kubelet and /var/lib/docker
- 12.2.26
* Mon Mar 13 2017 kanderssen@suse.com
- Added subvolume /var/lib/vmware (bsc#1028647)
- 12.2.25
* Tue Feb 28 2017 shundhammer@suse.de
- Added subvolumes /var/lib/kubelet and /var/lib/ntp (bsc#1026473)
- 12.2.24
* Thu Feb 16 2017 mfilka@suse.com
- fate#322328
  - appended (defaul) to "Administrative Dashboard" label to make
    it more obvious that such role will be used by default.
- 12.2.23
* Tue Feb  7 2017 jsrain@suse.cz
- remove installer update also from AutoYaST workflow (bsc#1024032)
- 12.2.22
* Tue Feb  7 2017 kanderssen@suse.com
- Removed additional dialog for worker role which is not used
  anymore (FATE#322328).
- 12.2.21
* Fri Feb  3 2017 igonzalezsosa@suse.com
- Remove AutoYaST second stage because it's not available in CaaSP
  (bsc#1022267)
- 12.2.20
* Thu Jan 26 2017 jreidinger@suse.com
- initial set of services adaptation for CASP roles (FATE#322328)
- 12.2.19
* Wed Jan 25 2017 mvidner@suse.com
- Use the all-in-one installation overview dialog (FATE#322328)
- 12.2.18
* Mon Jan 16 2017 igonzalezsosa@suse.com
- Set minimalistic configuration for libzypp (only required
  packages, no documentation and no multiversion)
  (FATE#321764)
- 12.2.17
* Mon Jan 16 2017 mfilka@suse.com
- fate#321739
  - use soft read-only flag for software proposal to allow
    modification in case of error
- 12.2.16
* Fri Jan 13 2017 jsrain@suse.cz
- Adjusted root filesystem minimal size (bsc#1019652)
- 12.2.15
* Fri Dec 23 2016 kanderssen@suse.com
- Added subvol for etcd without copy on write (bsc#1017145)
- 12.2.14
* Mon Dec 19 2016 shundhammer@suse.de
- Added subvol for docker, not libvirt (bsc#1015720)
- 12.2.13
* Wed Dec 14 2016 igonzalezsosa@suse.com
- Set timezone as read-only (FATE#321754).
- 12.2.12
* Wed Dec 14 2016 kanderssen@suse.com
- Added System Roles for CASP (FATE#321754).
- 12.2.11
* Wed Dec 14 2016 shundhammer@suse.de
- Added new parameter for CASP read-only Btrfs root subvolume
  (Fate#321755)
- 12.2.10
* Tue Dec 13 2016 jreidinger@suse.com
- Add keyboard and root password combined dialog to installation
  work-flow (FATE#321764)
- 12.2.9
* Mon Dec 12 2016 igonzalezsosa@suse.com
- Add /var/lib/machines to the list of default Btrfs subvolumes
  (bsc#1015071)
- 12.2.8
* Wed Dec  7 2016 schubi@suse.de
- Added default entry (clone_install_recommended_default) for
  "install_recommended" in created AutoYaST configuration file.
- Fate#321764
- 12.2.7
* Fri Dec  2 2016 schubi@suse.de
- Added CASP proposal. Cleanup proposal.
  (Fate#321754)
- 12.2.6
* Thu Dec  1 2016 mvidner@suse.com
- Simplified the installation workflow: removed these dialogs:
  license, add-ons, time, user (FATE#321754).
- Removed update+autoupgrade modes.
- 12.2.5
* Tue Nov 22 2016 igonzalezsosa@suse.com
- Remove desktop stuff as it's not needed in CASP
  (bsc#1011465) (author: Thorsten Kukuk)
- Replace var/lib/stateless by var/lib/overlay (bsc#1011466)
- 12.2.4
* Fri Nov 18 2016 lslezak@suse.cz
- Adjusted subvolumes configuration (fate#321737), disable firewall
  by default, install the CASP patterns (author: Thorsten Kukuk)
- 12.2.3
* Thu Nov 17 2016 shundhammer@suse.de
- Moved partitioning proposal out of workflow and into installation
  summary (Fate#321736)
- 12.2.2
* Thu Nov  3 2016 shundhammer@suse.de
- Added subvolumes (fate#321737)
- 12.2.1
* Fri Sep 30 2016 kukuk@suse.de
- Initial Version
